{
    SQL Browse Directory Dialog
    Copyright: Andrew Venmore (avenmore@ananzi.co.za)
    Ver: 1.0 (27 April 2004)
}

unit awvSQLBrowseDirUtils;

// ----------------------------------------------------------------------- //
                                  interface
// ----------------------------------------------------------------------- //
uses
  Classes, Forms, SysUtils, Controls;
// ----------------------------------------------------------------------- //

procedure PushCursor(NewCursor: TCursor = crHourGlass);
procedure PopCursor(const Totally: boolean = false);
function  BuildConnectionString(const AServer, AUser, APass, ADatabase: string): string;
function BackSlash(const APath: string): string;
function NoBackSlash(const APath: string): string;
procedure SplitString(AString: string; SepChar : char; ResultList: TStringList);

// ----------------------------------------------------------------------- //
                               implementation
// ----------------------------------------------------------------------- //

var
  CursorList: TList;

procedure PushCursor(NewCursor: TCursor = crHourGlass);
begin
  CursorList.Add(Pointer(Screen.Cursor));
  Screen.Cursor := NewCursor;
end;

procedure PopCursor(const Totally: boolean = false);
begin
  if (Totally) then begin
    Screen.Cursor := crDefault;
    CursorList.Clear;
  end
  else begin
    if (CursorList.Count > 0) then begin
      Screen.Cursor := TCursor(CursorList[CursorList.Count - 1]);
      CursorList.Delete(CursorList.Count - 1);
    end
    else
      Screen.Cursor := crDefault;
  end;
end;

function BuildConnectionString(const AServer, AUser, APass, ADatabase: string): string;
resourcestring
  sConnectionStringFmt = 'Provider=%s;Data Source=%s;Persist Security Info=False;Use Procedure for Prepare=1;Auto Translate=True;Packet Size=4096;';
  sProviderString = 'SQLOLEDB';
  sNTAuthLoginStr = 'Integrated Security=SSPI;';
  sSQLAuthLoginStr = 'User ID=%s;Password=%s;';
  sInitialDatabaseStr = 'Initial Catalog=%s;';
begin
  Result := Format(sConnectionStringFmt, [sProviderString, AServer]);
  if (AUser > '') then
    Result := Result + Format(sSQLAuthLoginStr, [AUser, APass])
  else
    Result := Result + sNTAuthLoginStr;
  if (ADatabase > '') then
    Result := Result + Format(sInitialDatabaseStr, [ADatabase]);
end;

function BackSlash (const APath: string): string;
begin
  Result := APath;
  if (Length (Result) >= 3) and (Result [Length (Result)] <> '\') then
    Result := Result + '\';
end;

function NoBackSlash (const APath: string): string;
begin
  Result := APath;
  if (Length (Result) >= 3) and ((Result [Length (Result)] = '\') or (Result [Length(Result)] = '/')) then
    Result := Copy (Result, 1, Length (Result) - 1);
end;

procedure SplitString(AString: string; SepChar : char; ResultList: TStringList);
begin
  if (Assigned (ResultList)) then begin
    ResultList.BeginUpdate;
    ResultList.Clear;
    if (AString > '') then begin
      repeat
        if (Pos (SepChar, AString) > 0) then begin
          ResultList.Add (Copy (AString, 1, Pos (SepChar, AString) - 1));
          AString := Copy (AString, Pos (SepChar, AString) + 1, Length (AString));
        end
        else begin
          ResultList.Add (AString);
          AString := '';
        end;

      until (AString = '');
    end;
    ResultList.EndUpdate;
  end;
end;

initialization
  CursorList := TList.Create;
finalization
  CursorList.Free;
end.

